@@ -130,6 +130,11 @@ class NodesController(RestController):
                 raise ClientSideError(
                     'Node {0} is missing a port'.format(node.address)
                 )
+            if node.port < 1 or node.port > 65535:
+                raise ClientSideError(
+                    'Node {0} port number {1} is invalid'
+                    .format(node.address, node.port)
+                )
             try:
                 node.address = ipfilter(node.address, conf.ip_filters)
             except IPOutOfRange:
@@ -190,10 +195,17 @@ class NodesController(RestController):
                     )
                 )
             device = session.query(
-                Device.id, Device.name
+                Device.id, Device.name, Device.status
             ).join(LoadBalancer.devices).\
                 filter(LoadBalancer.id == self.lbid).\
                 first()
+
+            if device.status == 'ERROR':
+                session.rollback()
+                raise ClientSideError(
+                    'Cannot modify a Load Balancer in an ERROR state'
+                )
+
             session.commit()
             submit_job(
                 'UPDATE', device.name, device.id, self.lbid
@@ -245,10 +257,17 @@ class NodesController(RestController):
 
             lb.status = 'PENDING_UPDATE'
             device = session.query(
-                Device.id, Device.name
+                Device.id, Device.name, Device.status
             ).join(LoadBalancer.devices).\
                 filter(LoadBalancer.id == self.lbid).\
                 first()
+
+            if device.status == 'ERROR':
+                session.rollback()
+                raise ClientSideError(
+                    'Cannot modify a Load Balancer in an ERROR state'
+                )
+
             session.commit()
             submit_job(
                 'UPDATE', device.name, device.id, lb.id
