@@ -19,12 +19,21 @@ class FakeOSServices(ServicesBase):
     def service_start(self):
         pass
 
+    def service_reload(self):
+        pass
+
     def write_config(self, config_str):
         pass
 
     def remove_configs(self):
         pass
 
+    def sudo_rm(self, file):
+        pass
+
+    def syslog_restart(self):
+        pass
+
 
 class FakeFaultingOSServices(ServicesBase):
     def service_stop(self):
@@ -33,6 +42,9 @@ class FakeFaultingOSServices(ServicesBase):
     def service_start(self):
         raise Exception("fault")
 
+    def service_reload(self):
+        raise Exception("fault")
+
     def service_restart(self):
         raise Exception("fault")
 
